==> wimlib-0.4.8.tar.gz: wimlib-0.4.8/src/xpress.h <==
/*
 * xpress.h
 *
 * wimlib - Library for working with WIM files 
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to the Free Software Foundation, Inc., 59
 * Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */

#ifndef _WIMLIB_XPRESS_H
#define _WIMLIB_XPRESS_H

/* See the comments in xpress-decomp.c about the XPRESS format. */

#define ENABLE_XPRESS_VERIFY

//#define ENABLE_XPRESS_DEBUG
#ifdef ENABLE_XPRESS_DEBUG
#	define XPRESS_DEBUG DEBUG
#else
#	define XPRESS_DEBUG(format, ...)
#endif

#define XPRESS_NUM_CHARS	256
#define XPRESS_NUM_SYMBOLS	512
#define XPRESS_MAX_CODEWORD_LEN	16
#define XPRESS_TABLEBITS	12

#define XPRESS_MIN_MATCH_LEN	3
#define XPRESS_MAX_MATCH_LEN    0xff

bool xpress_decompress(const void *__compressed_data, int compressed_len, 
			void *__uncompressed_data, int uncompressed_len);

bool xpress_compress(const void *uncompressed_data, unsigned uncompressed_len,
			void *compressed_data, unsigned *compressed_len_ret);

#endif /* _WIMLIB_XPRESS_H */

==> wimlib-0.5.0.tar.gz: wimlib-0.5.0/src/xpress.h <==
/*
 * xpress.h
 *
 * wimlib - Library for working with WIM files 
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to the Free Software Foundation, Inc., 59
 * Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */

#ifndef _WIMLIB_XPRESS_H
#define _WIMLIB_XPRESS_H

/* See the comments in xpress-decomp.c about the XPRESS format. */

//#define ENABLE_XPRESS_DEBUG
#ifdef ENABLE_XPRESS_DEBUG
#	define XPRESS_DEBUG DEBUG
#else
#	define XPRESS_DEBUG(format, ...)
#endif

#define XPRESS_NUM_CHARS	256
#define XPRESS_NUM_SYMBOLS	512
#define XPRESS_MAX_CODEWORD_LEN	15
#define XPRESS_TABLEBITS	12

#define XPRESS_MIN_MATCH	3
#define XPRESS_MAX_MATCH    	255

bool xpress_decompress(const void *__compressed_data, int compressed_len, 
			void *__uncompressed_data, int uncompressed_len);

bool xpress_compress(const void *uncompressed_data, unsigned uncompressed_len,
			void *compressed_data, unsigned *compressed_len_ret);

#endif /* _WIMLIB_XPRESS_H */
